Constant - LatentLego

Skip to content

# Constant

### `latent.layers.DenseStack`

A stack of `DenseBlock` layers.

#### `__init__(self, name=None, hidden_units=[128, 128], conditional=None, **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`name` | `str` | String indicating the name of the layer. | `None`
`hidden_units` | `Iterable[int]` | Iterable of number hidden units per layer. All layers are fully connected. Ex. [128, 64] means first layer has 128 nodes and second one has 64. | `[128, 128]`
`conditional` | `Literal['first', 'all']` | One of the following: `'first'` Inject condition into first layer `'all'` Inject condition into all layers `None` Don't inject condition | `None`
`**kwargs` | `` | Other arguments passed on to `DenseBlock`. | `{}`